pub fn cursor_style(shape: CursorShape) -> SetCursorStyleExpand description
Map a terminal cursor shape to the corresponding crossterm cursor style.
pub fn cursor_style(shape: CursorShape) -> SetCursorStyleMap a terminal cursor shape to the corresponding crossterm cursor style.